;********************************************************************
;*                      Program za novoletno jelko.                 *
;********************************************************************

	SUBTITL "Utripajoca in pojoca novoletna jelka"
;	LIST     P=16C84,N=40,C=132

;********************************************************************
;*                      Register Assignments                        *
;********************************************************************

indir   equ     0x00            ; Use this register as source/destination for
				; indirect addressing.
rtcc    equ     0x01            ; real time clock/counter
pcl     equ     0x02            ; PIC Program Counter.
status  equ     0x03            ; PIC Status Register.
fsr     equ     0x04            ; File Select Register.

eedata  equ     0x08            ; EE podatkovni register
eeadr   equ     0x09            ; EE naslovni register
eecon1  equ     0x08            ; kontrolni register 1
eecon2  equ     0x09            ; kontrolni register 2
intcon  equ     0x0B            ; interrupt kontrolni register

pclath  equ     0x0A

porta   equ     0x05            ; port A data register
trisa   equ     0x05            ; port A data direction register

portb   equ     0x06            ; port B data register
trisb   equ     0x06            ; port B data direction register

carry   equ     0               ; Carry Flag of Status Register.
zflag   equ     2               ; Zero Flag of Status Register.
rp0     equ     5               ; Register page select bit
irp     equ     7               ; General purpose bit (only 16c84) !!!!!!!!
w       equ     0               ; Work register
f       equ     1               ; file register (data RAM)

rtif    equ     2               ; RTCC interrupt flag
rtie    equ     5               ; RTCC interrupt enable
gie     equ     7               ; general interrupt enable

uni_01  equ     0x0C            ; univerzalna pomnilna lokacija
uni_02  equ     0x0D            ; univerzalna pomnilna lokacija
uni_03  equ     0x0E            ; univerzalna pomnilna lokacija
uni_04  equ     0x0F            ; univerzalna pomnilna lokacija

koef_d  equ     0x10            ; koeficient deljenja Fosc/4
tone    equ     0x11            ; podatek o tonu
ritem   equ     0x12            ; ritem melodije (100 = 60 udarcev/min)
stack   equ     0x13            ; stack prekinitve za W register
st_ton  equ     0x14            ; stevec trenutno izvajanega tona
st_tip  equ     0x15            ; stevec pritisnjenosti tipke
komb_0  equ     0x16            ; spodnji byte shift registra
komb_1  equ     0x17            ; gornji byte shift registra
log_0   equ     0x18            ; logicna sprem. 0
log_1   equ     0x19            ; logicna sprem. 1
st_cak0 equ     0x1A            ; stevec cakanja
st_cak1 equ     0x1B            ; stevec cakanja
zac_kom equ     0x1C            ; zacasna kombinacija
pav_kmb equ     0x1D            ; pavza med kombinacijami v sek. (0...3)

tipka   equ     0               ; tipka na RA0
zv1     equ     2               ; zvocnik na RA2
zv2     equ     3               ; zvocnik na RA3


	org     0x0000
	goto    reset

	org     0x0004
	goto    int_rtcc        ; prekinitev RTCC

;********************************************************************
;*                      Reset                                       *
;********************************************************************
	org     0x0010
reset
	clrf    pclath
	clrwdt
	movlw   b'11011111'
	option
	clrwdt

;********************************************************************
;*      Inicializacija vhodov/izhodov                               *
;********************************************************************
	movlw   b'00001111'     ; port A: visoko stanje razen RTCC
	movwf   porta
	movlw   b'11111111'     ; port B: visoko stanje (LEDs off)
	movwf   portb
	bsf     status,rp0      ; dostop do gornje polovice file registrov
	movlw   b'11100001'     ; konfiguracija port A (tipka - vhod)
	movwf   trisa
	movlw   b'00000000'     ; konfiguracija port B izhodi na LED
	movwf   trisb
	bcf     status,rp0      ; ponovno dostop do spod. polov. file regist.
	
	movlw   0x20            ; ca 100 ms da zazna pritisnjeno tipko
	movwf   st_tip          ; dam v stevec tipke

	movlw   0x02            ; privzeta pavza 2 sek.
	btfss   porta,tipka     ; ce tipka pritisnjena, 
	movlw   0x01            ; pavza le 1 sek.
	movwf   pav_kmb         ; inicializiram sprem., ki doloca traj. pav.
	movlw   0xAA        
	movwf   portb           ; prizgem nekaj LEDic

	movlw   0xFF
	movwf   komb_1          ; zgornji del shift registra
	clrf    komb_0          ; spodnji del shift registra

;********************************************************************
;*      Glavna zanka.                                               *
;********************************************************************
zanka

melodija_1        
	call    cakaj           ; caka na tipko in utripa lucke
	
	movlw   0x28            ; prej 28 (za 27p, 30k)
	movwf   ritem           ; ritem Larine pesmi
	movlw   0x00
	movwf   st_ton          ; prvi ton pesmi_1
	movlw   0x29            ; trajanje pesmi_1 je 41 tonov        
	movwf   uni_04          ; stevec trajanja pesmi
zanka_1
	movlw   0x02            ; zacetek bloka pesmi_1
	movwf   pclath          ; nastavim PCLATH da bo skok OK
	movf    st_ton,w        ; stev. trenutnega tona        
	call    pesem_1         ; trenutni ton
	movwf   tone            ; podatek o tonu
	clrf    pclath          ; PCLATH znova na zacetno vrednost
	call    ton             ; ton odigram

	andlw   0xFF            ; preverjanje, ali je bila pritisnjena tipka
	btfss   status,zflag
	goto    melodija_2

	incf    st_ton,f        ; naslednji ton
	decfsz  uni_04,f        ; ali odigrana cela pesem, ce da preskoci goto
	goto    zanka_1         ; se ne
melodija_2
	call    cakaj           ; caka na tipko in utripa lucke
	
	movlw   0x45            ; prej 45            
	movwf   ritem           ; ritem Jingle Bells
	movlw   0x00
	movwf   st_ton          ; prvi ton pesmi_2
	movlw   0x71            ; trajanje pesmi_2 je 113 tonov        
	movwf   uni_04          ; stevec trajanja pesmi
zanka_2
	movlw   0x02            ; zacetek bloka pesmi_2
	movwf   pclath          ; nastavim PCLATH da bo skok OK
	movf    st_ton,w        ; stev. trenutnega tona        
	call    pesem_2         ; trenutni ton
	movwf   tone            ; podatek o tonu
	clrf    pclath          ; PCLATH znova na zacetno vrednost
	call    ton             ; ton odigram

	andlw   0xFF            ; preverjanje, ali je bila pritisnjena tipka
	btfss   status,zflag
	goto    melodija_3

	incf    st_ton,f        ; naslednji ton
	decfsz  uni_04,f        ; ali odigrana cela pesem, ce da preskoci goto
	goto    zanka_2         ; se ne
melodija_3        
	call    cakaj           ; caka na tipko in utripa lucke
	
	movlw   0x39            ; prej 39
	movwf   ritem           ; ritem Edelweiss
	movlw   0x00
	movwf   st_ton          ; prvi ton pesmi_3
	movlw   0x37            ; trajanje pesmi_3 je 55 tonov        
	movwf   uni_04          ; stevec trajanja pesmi
zanka_3
	movlw   0x02            ; zacetek bloka pesmi_3
	movwf   pclath          ; nastavim PCLATH da bo skok OK
	movf    st_ton,w        ; stev. trenutnega tona        
	call    pesem_3         ; trenutni ton
	movwf   tone            ; podatek o tonu
	clrf    pclath          ; PCLATH znova na zacetno vrednost
	call    ton             ; ton odigram

	andlw   0xFF            ; preverjanje, ali je bila pritisnjena tipka
	btfss   status,zflag
	goto    melodija_4

	incf    st_ton,f        ; naslednji ton
	decfsz  uni_04,f        ; ali odigrana cela pesem, ce da preskoci goto
	goto    zanka_3         ; se ne
melodija_4
	call    cakaj           ; caka na tipko in utripa lucke
	
	movlw   0x50            ; prej 50
	movwf   ritem           ; ritem Sveta noc
	movlw   0x00
	movwf   st_ton          ; prvi ton pesmi_4
	movlw   0x2E            ; trajanje pesmi_4 je 46 tonov        
	movwf   uni_04          ; stevec trajanja pesmi
zanka_4
	movlw   0x03            ; zacetek bloka pesmi_4
	movwf   pclath          ; nastavim PCLATH da bo skok OK
	movf    st_ton,w        ; stev. trenutnega tona        
	call    pesem_4         ; trenutni ton
	movwf   tone            ; podatek o tonu
	clrf    pclath          ; PCLATH znova na zacetno vrednost
	call    ton             ; ton odigram

	andlw   0xFF            ; preverjanje, ali je bila pritisnjena tipka
	btfss   status,zflag
	goto    melodija_5

	incf    st_ton,f        ; naslednji ton
	decfsz  uni_04,f        ; ali odigrana cela pesem, ce da preskoci goto
	goto    zanka_4         ; se ne
melodija_5
	call    cakaj           ; caka na tipko in utripa lucke
	
	movlw   0x58            ; prej 58
	movwf   ritem           ; ritem Love me tender
	movlw   0x00
	movwf   st_ton          ; prvi ton pesmi_5
	movlw   0x4A            ; trajanje pesmi_5 je 74 tonov        
	movwf   uni_04          ; stevec trajanja pesmi
zanka_5
	movlw   0x03            ; zacetek bloka pesmi_5
	movwf   pclath          ; nastavim PCLATH da bo skok OK
	movf    st_ton,w        ; stev. trenutnega tona        
	call    pesem_5         ; trenutni ton
	movwf   tone            ; podatek o tonu
	clrf    pclath          ; PCLATH znova na zacetno vrednost
	call    ton             ; ton odigram

	andlw   0xFF            ; preverjanje, ali je bila pritisnjena tipka
	btfss   status,zflag
	goto    melodija_6

	incf    st_ton,f        ; naslednji ton
	decfsz  uni_04,f        ; ali odigrana cela pesem, ce da preskoci goto
	goto    zanka_5         ; se ne
melodija_6
	call    cakaj           ; caka na tipko in utripa lucke
	
	movlw   0x3A            ; prej 3A
	movwf   ritem           ; ritem "Oh when the saints, go marchin`in"
	movlw   0x00
	movwf   st_ton          ; prvi ton pesmi_6
	movlw   0x25            ; trajanje pesmi_6 je 37 tonov        
	movwf   uni_04          ; stevec trajanja pesmi
zanka_6
	movlw   0x03            ; zacetek bloka pesmi_6
	movwf   pclath          ; nastavim PCLATH da bo skok OK
	movf    st_ton,w        ; stev. trenutnega tona        
	call    pesem_6         ; trenutni ton
	movwf   tone            ; podatek o tonu
	clrf    pclath          ; PCLATH znova na zacetno vrednost
	call    ton             ; ton odigram

	andlw   0xFF            ; preverjanje, ali je bila pritisnjena tipka
	btfss   status,zflag
	goto    melodija_7

	incf    st_ton,f        ; naslednji ton
	decfsz  uni_04,f        ; ali odigrana cela pesem, ce da preskoci goto
	goto    zanka_6         ; se ne
melodija_7
	call    cakaj           ; caka na tipko in utripa lucke
	
	movlw   0x40            ; prej 40
	movwf   ritem           ; ritem "My bonnie is over the ocean"
	movlw   0x00
	movwf   st_ton          ; prvi ton pesmi_7
	movlw   0x3E            ; trajanje pesmi_7 je 62 tonov        
	movwf   uni_04          ; stevec trajanja pesmi
zanka_7
	movlw   0x03            ; zacetek bloka pesmi_7
	movwf   pclath          ; nastavim PCLATH da bo skok OK
	movf    st_ton,w        ; stev. trenutnega tona        
	call    pesem_7         ; trenutni ton
	movwf   tone            ; podatek o tonu
	clrf    pclath          ; PCLATH znova na zacetno vrednost
	call    ton             ; ton odigram

	andlw   0xFF            ; preverjanje, ali je bila pritisnjena tipka
	btfss   status,zflag
	goto    melodija_8

	incf    st_ton,f        ; naslednji ton
	decfsz  uni_04,f        ; ali odigrana cela pesem, ce da preskoci goto
	goto    zanka_7         ; se ne
melodija_8
	call    cakaj           ; caka na tipko in utripa lucke
	
	movlw   0x28            ; prej 28
	movwf   ritem           ; ritem "All My Loving"
	movlw   0x00
	movwf   st_ton          ; prvi ton pesmi_8
	movlw   0x3E            ; trajanje pesmi_8 je 62 tonov        
	movwf   uni_04          ; stevec trajanja pesmi
zanka_8
	movlw   0x01            ; zacetek bloka pesmi_9
	movwf   pclath          ; nastavim PCLATH da bo skok OK
	movf    st_ton,w        ; stev. trenutnega tona        
	call    pesem_8         ; trenutni ton
	movwf   tone            ; podatek o tonu
	clrf    pclath          ; PCLATH znova na zacetno vrednost
	call    ton             ; ton odigram

	andlw   0xFF            ; preverjanje, ali je bila pritisnjena tipka
	btfss   status,zflag
	goto    melodija_9

	incf    st_ton,f        ; naslednji ton
	decfsz  uni_04,f        ; ali odigrana cela pesem, ce da preskoci goto
	goto    zanka_8         ; se ne
melodija_9

	goto    zanka

;********************************************************************
;*      Podprogram utripa lucke brez melodije in caka na tip.  ali 30 min. 
;********************************************************************
cakaj        
	movlw   0x20            ; ca 100 ms da zazna pritisnjeno tipko
	movwf   st_tip          ; dam v stevec tipke
	btfss   porta,tipka     ; ce tipka spuscena, preskoci nasl. uk.
	goto    cakaj

	movlw   0x19            ; ca 60. min caka, potem odigra melodijo
	movwf   st_cak1
cakaj_zz
	movlw   0x60            ; za ca. 120 sek
	movwf   st_cak0
cakaj_z
	call    kombinacija     ; prizgi novo kombinacijo LED, nato pavza

	movf    pav_kmb,w
	andlw   b'00000011'
	movwf   uni_01          ; stevec zunanje zanke, ca. 1.5 s pavze
cakaj_z1        
	movlw   0xF0
	movwf   uni_02          ; stevec srednje zanke
cakaj_z2                         
	btfsc   porta,tipka     ; ce tipka pritisnjena, preskoci nasl. uk.
	goto    cakaj_ni_tipka
	decfsz  st_tip,f        ; stejem pritisnjenost tipke
	goto    cakaj_je_tipka  ; se ni pritisnjena dovolj casa

cakaj_spust        
	movlw   0x20            ; ca 100 ms da zazna pritisnjeno tipko
	movwf   st_tip          ; dam v stevec tipke
	btfss   porta,tipka     ; ce tipka spuscena, preskoci nasl. uk.
	goto    cakaj_spust
	return                  ; vrnitev v glavni program
	
cakaj_ni_tipka
	movlw   0x20            ; ca. 100 ms, da zazna pritisnjeno tipko
	movwf   st_tip          ; dam v stevec tipke
cakaj_je_tipka        
	movlw   0x62            ; 98 x 5 + 8 = 498
	movwf   uni_03          ; stevec notranje zanke
cakaj_z3
	nop                     ; 1
	nop                     ; 1
	nop                     ; 1
	decfsz  uni_03,f        ; 1
	goto    cakaj_z3        ; 1

	decfsz  uni_02,f        ; 1
	goto    cakaj_z2        ; 1

	decfsz  uni_01,f        ; 1
	goto    cakaj_z1        ; 1

	decfsz  st_cak0,f
	goto    cakaj_z
	decfsz  st_cak1,f       ; ali sem docakal 15 min., ce da, preskoci
	goto    cakaj_zz        ; nisem se docakal naslednje melodije

	movlw   0x20            ; ca 100 ms da zazna pritisnjeno tipko
	movwf   st_tip          ; dam v stevec tipke
	return                  ; vrnitev v glavni program

;********************************************************************
;*      Podprogram za realizacijo tona, visina in traj. v tone.     *
;********************************************************************
ton
	movlw   0x04
	movwf   uni_01
ton_z02
	clrf    uni_02
ton_z03
	decfsz  uni_02,f
	goto    ton_z03
	decfsz  uni_01,f
	goto    ton_z02
	
	movf    tone,w
	andlw   0x0F            ; nizji stirje biti so visina tona
	movwf   uni_01
	incf    uni_01,f
	decfsz  uni_01,f
	goto    ton_s01
	call    kombinacija     ; ce pavza, potem kombinacija
	goto    ton_s02        
ton_s01
	bsf     status,carry
	clrf    uni_02       
ton_z01
	rlf     uni_02,f
	decfsz  uni_01,f
	goto    ton_z01        
	
	btfsc   status,carry    ; ce 1 v carry, potem das 1 v LSB od uni_02
	rrf     uni_02,f        ; dam carry v MSB
	
	btfsc   uni_02,0        ; ce 1 v LSB, ki ne poganja LED
	rlf     uni_02,f        ; dam 1 v uni_02.1

	comf    uni_02,w
	movwf   zac_kom         ; nova vrednost za izhode (port B), pocakam
ton_s02
	movlw   0x20            ; ca. 100 ms, da zazna pritisnjeno tipko
	movwf   st_tip          ; dam v stevec tipke
	
	movf    tone,w                
	andlw   0x0F            ; upostevam le nizje stiri bite (visina tona)
	
	btfsc   status,zflag    ; ce nic, potem zero = 1
	goto    no_tone         ; zahteva za pavzo, brez tona
	movwf   uni_01
	decfsz  uni_01,f        ; ce hi nible of tone = 1, potem preskoci
	goto    ton_s1
	movlw   0x0F            ; 256 - 250 + 9 => 1000 Hz
	goto    ton_start
ton_s1
	decfsz  uni_01,f        ; ce hi nible of tone = 2, potem preskoci
	goto    ton_s2
	movlw   0x1D            ; 256 - 236 + 9 => 1059 Hz
	goto    ton_start
ton_s2
	decfsz  uni_01,f        ; ce hi nible of tone = 3, potem preskoci
	goto    ton_s3
	movlw   0x2A            ; 256 - 223 + 9 => 1122 Hz
	goto    ton_start
ton_s3
	decfsz  uni_01,f        ; ce hi nible of tone = 4, potem preskoci
	goto    ton_s4
	movlw   0x37            ; 256 - 210 + 9 => 1189 Hz
	goto    ton_start
ton_s4
	decfsz  uni_01,f        ; ce hi nible of tone = 1, potem preskoci
	goto    ton_s5
	movlw   0x43            ; 256 - 198 + 9 => 1260 Hz
	goto    ton_start
ton_s5
	decfsz  uni_01,f        ; ce hi nible of tone = 1, potem preskoci
	goto    ton_s6
	movlw   0x4E            ; 256 - 187 + 9 => 1335 Hz
	goto    ton_start
ton_s6
	decfsz  uni_01,f        ; ce hi nible of tone = 1, potem preskoci
	goto    ton_s7
	movlw   0x58            ; 256 - 177 + 9 => 1414 Hz
	goto    ton_start
ton_s7
	decfsz  uni_01,f        ; ce hi nible of tone = 1, potem preskoci
	goto    ton_s8
	movlw   0x62            ; 256 - 167 + 9 => 1498 Hz
	goto    ton_start
ton_s8
	decfsz  uni_01,f        ; ce hi nible of tone = 1, potem preskoci
	goto    ton_s9
	movlw   0x6C            ; 256 - 157 + 9 => 1587 Hz
	goto    ton_start
ton_s9
	decfsz  uni_01,f        ; ce hi nible of tone = 1, potem preskoci
	goto    ton_s10
	movlw   0x74            ; 256 - 149 + 9 => 1681 Hz
	goto    ton_start
ton_s10
	decfsz  uni_01,f        ; ce hi nible of tone = 1, potem preskoci
	goto    ton_s11
	movlw   0x7D            ; 256 - 140 + 9 => 1782 Hz
	goto    ton_start
ton_s11
	decfsz  uni_01,f        ; ce hi nible of tone = 1, potem preskoci
	goto    ton_s12
	movlw   0x85            ; 256 - 132 + 9 => 1888 Hz
	goto    ton_start
ton_s12
	decfsz  uni_01,f        ; ce hi nible of tone = 1, potem preskoci
	goto    ton_s13
	movlw   0x8C            ; 256 - 125 + 9 => 2000 Hz
	goto    ton_start
ton_s13
	decfsz  uni_01,f        ; ce hi nible of tone = 1, potem preskoci
	goto    ton_s14
	movlw   0x93            ; 256 - 118 + 9 => 2119 Hz
	goto    ton_start
ton_s14
	decfsz  uni_01,f        ; ce hi nible of tone = 1, potem preskoci
	goto    ton_start
	movlw   0x9A            ; 256 - 111 + 9 => 2245 Hz
ton_start
	movwf   koef_d
	bsf     porta,zv1
	bcf     porta,zv2       ; protifazno delovanje
	
	movwf   rtcc            ; nekaj pavze do prve prekinitve
	bsf     intcon,rtie     ; omogocim prekinitev tim. modula
	bsf     intcon,gie      ; generalna prekinitev omogocena
	
	movf    zac_kom,w
	movwf   portb
no_tone        
	swapf   tone,w          ; gornji stirje biti pomenijo dolzino        
	andlw   0x0F            ; le spodnji stirje biti so dolzina
	movwf   uni_01          ; stevec zunanje zanke        
ton_z1        
	movf    ritem,w
	movwf   uni_02          ; stevec srednje zanke (ritem x 624+4 = 50404)
ton_z2                          ; 49904 x 2 + prek. = ca.125 msec (osminka)
	btfsc   porta,tipka     ; ce tipka pritisnjena, preskoci nasl. uk.
	goto    ton_ni_tipka
	decfsz  st_tip,f        ; stejem pritisnjenost tipke
	goto    ton_je_tipka    ; se ni pritisnjena dovolj casa

	bcf     intcon,gie      ; generalna prekinitev onemogocena
	bcf     intcon,rtie     ; onemogocim prekinitev tim. modula
	bsf     porta,zv1
	bsf     porta,zv2       ; zvocnik v nevtralno stanje
	
	movlw   0xFF
	movwf   portb

	movlw   0x20            ; ca. 100 ms da zazna pritisnjeno tipko
	movwf   st_tip          ; dam v stevec tipke
	
	retlw   0xFF            ; signal, da je bila tipka pritisnjena
	
ton_ni_tipka
	movlw   0x20            ; ca. 100 ms, da zazna pritisnjeno tipko
	movwf   st_tip          ; dam v stevec tipke
ton_je_tipka        
	movlw   0x62            ; 98 x 5 + 8 = 498
	movwf   uni_03          ; stevec notranje zanke
ton_z3
	nop                     ; 1
	nop                     ; 1
	nop                     ; 1
	decfsz  uni_03,f        ; 1
	goto    ton_z3          ; 1

	decfsz  uni_02,f        ; 1
	goto    ton_z2          ; 1

	decfsz  uni_01,f        ; 1
	goto    ton_z1          ; 1

	bcf     intcon,gie      ; generalna prekinitev onemogocena
	bcf     intcon,rtie     ; onemogocim prekinitev tim. modula
	bsf     porta,zv1
	bsf     porta,zv2       ; zvocnik v nevtralno stanje
	
	movlw   0xFF
	movwf   portb
	
	movlw   0x20            ; ca 100 ms da zazna pritisnjeno tipko
	movwf   st_tip          ; dam v stevec tipke

	retlw   0x00            ; signal, da ni pritisnjena tipka

;********************************************************************
;*      Podprogram prizge novo kombinacijo LED.                     *
;********************************************************************
kombinacija
	movlw   0x08            ; 8 krat shiftam navzgor (v levo)        
	movwf   uni_02
komb_z1        
	movf    komb_0,w
	movwf   log_0
	movf    komb_1,w
	movwf   log_1
	
	rrf     log_0,f         ; b1 v spodnjo lokacijo
	
	rlf     log_1,f
	rlf     log_1,f
	rlf     log_1,f         ; b14 v spodnjo lokacijo
	
	movlw   0x01
	andwf   log_0,f
	andwf   log_1,f         ; ostali biti na 0
	
	movf    log_0,w
	andwf   log_1,w
	movwf   uni_01          ; b1 & b0 --> uni_01

	
	comf    log_0,f         ; neg. b0
	comf    log_1,f         ; neg. b1
	
	movlw   0x01
	andwf   log_0,f
	andwf   log_1,f         ; ostali biti na 0
	
	movf    log_0,w
	andwf   log_1,w         ; 'b1 ^ 'b14 --> w
	
	iorwf   uni_01,f        ; w ali uni_01 --> uni_01

	rrf     uni_01,f
	rlf     komb_0,f
	rlf     komb_1,f

	decfsz  uni_02,f        ; ali sem ze 8 krat shiftal, ce da preskoci
	goto    komb_z1         ; ne, ponovi

	movf    komb_0,w
	movwf   portb           ; nova psevdonaklj. vred. na izhode (port B)

	return

;********************************************************************
;*      Prekinitev RTCC.                                            *
;********************************************************************
int_rtcc                        ; 4 cikle za vstop
	movwf   stack           ; 1 shranim w, da ne porusim pavze ("stack")
	movf    koef_d,w        ; 1
	movwf   rtcc            ; 1
				; 2 cikla, ko se rtcc ne obraca
	movlw   b'00001100'
	xorwf   porta,f         ; zamenjam vrednosti bitov zv1 in zv2
	movf    stack,w         ; vzamem w s "stacka" (stack = uni_04)                                

	bcf     intcon,rtif
	retfie

;********************************************************************
;*      Tabele pesmic.                                              *
;********************************************************************

;********************************************************************
;*      All my Loving                                               *
;********************************************************************
pesem_8                         ; dolzina pesmi 62 tonov
	addwf   pcl,f

	retlw   0x27
	retlw   0x26

	retlw   0x44
	retlw   0x26
	retlw   0x27

	retlw   0x29
	retlw   0x4B
	retlw   0x2D

	retlw   0x4E
	retlw   0x2E
	retlw   0x2D

	retlw   0x2B
	retlw   0x46
	retlw   0x2B

	retlw   0x4B
	retlw   0x2B
	retlw   0x29

	retlw   0x47
	retlw   0x24
	retlw   0x22

	retlw   0xC4
	retlw   0x27
	retlw   0x26

	retlw   0x44
	retlw   0x26
	retlw   0x27

	retlw   0x49
	retlw   0x2B
	retlw   0x2D

	retlw   0x4E
	retlw   0x2E
	retlw   0x2D

	retlw   0x2B
	retlw   0x46
	retlw   0x1B
	retlw   0x1B

	retlw   0x4B
	retlw   0x2B
	retlw   0x29
	
	retlw   0x27
	retlw   0x46
	retlw   0x24

	retlw   0xC2

	retlw   0x2E
	retlw   0x2D

	retlw   0x2B
	retlw   0x66

	retlw   0x26
	retlw   0x24
	retlw   0x22
	retlw   0x24

	retlw   0xC6
	retlw   0x2E
	retlw   0x2D

	retlw   0x2B
	retlw   0x66

	retlw   0x26
	retlw   0x24
	retlw   0x22
	retlw   0x22

	retlw   0xA2

	retlw   0x80


	org     0x210           
;********************************************************************
;*      Larina pesem                                                *
;********************************************************************
pesem_1                         ; dolzina pesmi 41 tonov
	addwf   pcl,f           ; 512. byte

	retlw   0x61            
	retlw   0x44              
	retlw   0x2C 
	retlw   0xCD              
	
	retlw   0x28
	retlw   0x2B              
	retlw   0x29  
	retlw   0x44              
	retlw   0x23 
	retlw   0xC2              

	retlw   0x62 
	retlw   0x44              
	retlw   0x26 
	retlw   0xC8              
	
	retlw   0x26
	retlw   0x24              
	retlw   0x23  
	retlw   0x44              
	retlw   0x2E 
	retlw   0xCD              
	
	retlw   0x61 
	retlw   0x44              
	retlw   0x2C 
	retlw   0xCD              
	
	retlw   0x28
	retlw   0x2B              
	retlw   0x29  
	retlw   0x44              
	retlw   0x23 
	retlw   0xC2              

	retlw   0x62 
	retlw   0x44              
	retlw   0x26 
	retlw   0xC8              
	
	retlw   0x26
	retlw   0x24              
	retlw   0x23  
	retlw   0x44              
	retlw   0x2B 
	retlw   0x89            
	
	retlw   0x80    ; 553. byte

;********************************************************************
;*      Jingle bells                                                *
;********************************************************************
pesem_2                         ; dolzina pesmi 113 tonov
	addwf   pcl,f           ; 554. byte

	retlw   0x1A            ; 1
	retlw   0x1A
	retlw   0x2A

	retlw   0x1A            ; 2
	retlw   0x1A
	retlw   0x2A

	retlw   0x1A            ; 3
	retlw   0x1D
	retlw   0x16
	retlw   0x18
				
	retlw   0x4A            ; 4

	retlw   0x1B            ; 5
	retlw   0x1B
	retlw   0x2B

	retlw   0x1A            ; 6
	retlw   0x1A
	retlw   0x2A

	retlw   0x18            ; 7
	retlw   0x18
	retlw   0x18
	retlw   0x1A
				
	retlw   0x28            ; 8
	retlw   0x2D

	retlw   0x1A            ; 91
	retlw   0x1A
	retlw   0x2A

	retlw   0x1A            ; 92
	retlw   0x1A
	retlw   0x2A

	retlw   0x1A            ; 93
	retlw   0x1D
	retlw   0x16
	retlw   0x18
				
	retlw   0x4A            ; 94

	retlw   0x1B            ; 95
	retlw   0x1B
	retlw   0x2B

	retlw   0x1A            ; 96
	retlw   0x1A              
	retlw   0x2A

	retlw   0x1D            ; 10
	retlw   0x1B
	retlw   0x1A
	retlw   0x18
				
	retlw   0x46            ; 11

	retlw   0x11            ; 12
	retlw   0x1A
	retlw   0x18
	retlw   0x16
				
	retlw   0x41            ; 13

	retlw   0x11            ; 14
	retlw   0x1A
	retlw   0x18
	retlw   0x16
				
	retlw   0x43            ; 15

	retlw   0x13            ; 16
	retlw   0x1B
	retlw   0x1A
	retlw   0x18
				
	retlw   0x1D            ; 17
	retlw   0x1D
	retlw   0x2D
				
	retlw   0x1F            ; 18
	retlw   0x1D
	retlw   0x18
	retlw   0x19
				
	retlw   0x4A            ; 19

	retlw   0x11            ; 20_12
	retlw   0x1A
	retlw   0x18
	retlw   0x16
				
	retlw   0x41            ; 20_13

	retlw   0x11            ; 20_14
	retlw   0x1A
	retlw   0x18
	retlw   0x16
				
	retlw   0x43            ; 20_15

	retlw   0x13            ; 20_16
	retlw   0x1B
	retlw   0x1A
	retlw   0x18
				
	retlw   0x1D            ; 20_17
	retlw   0x1D
	retlw   0x2D
				
	retlw   0x1F            ; 21
	retlw   0x1D
	retlw   0x1B
	retlw   0x18
				
	retlw   0x26            ; 22
	retlw   0x2D

	retlw   0x1A            ; 23_91
	retlw   0x1A
	retlw   0x2A

	retlw   0x1A            ; 23_92
	retlw   0x1A
	retlw   0x2A

	retlw   0x1A            ; 23_93
	retlw   0x1D
	retlw   0x16
	retlw   0x18
				
	retlw   0x4A            ; 23_94

	retlw   0x1B            ; 23_95
	retlw   0x1B
	retlw   0x2B

	retlw   0x1A            ; 23_96
	retlw   0x1A              
	retlw   0x2A

	retlw   0x1D            ; 23_10
	retlw   0x1B
	retlw   0x1A
	retlw   0x18
				
	retlw   0x46            ; 23_11 
	
	retlw   0x80            ; 667. byte

;********************************************************************
;*      Edelweiss                                                   *
;********************************************************************
pesem_3                         ; dolzina pesmi    tonov
	addwf   pcl,f           ; 668. byte

	retlw   0x43
	retlw   0x26

	retlw   0x6d

	retlw   0x4B
	retlw   0x26

	retlw   0x64

	retlw   0x43
	retlw   0x23

	retlw   0x23
	retlw   0x24
	retlw   0x26
	
	retlw   0x68

	retlw   0x66

	retlw   0x43
	retlw   0x26

	retlw   0x6D

	retlw   0x4B
	retlw   0x26

	retlw   0x64

	retlw   0x43
	retlw   0x26

	retlw   0x26
	retlw   0x28
	retlw   0x2A

	retlw   0x6B

	retlw   0x4B
	retlw   0x20

	retlw   0x4D
	retlw   0x26

	retlw   0x2A
	retlw   0x28
	retlw   0x26

	retlw   0x43
	retlw   0x26

	retlw   0x6B

	retlw   0x48
	retlw   0x2B

	retlw   0x4D
	retlw   0x2B

	retlw   0x6A

	retlw   0x66

	retlw   0x43
	retlw   0x26

	retlw   0x6D

	retlw   0x4B
	retlw   0x26

	retlw   0x64

	retlw   0x43
	retlw   0x26

	retlw   0x26
	retlw   0x28
	retlw   0x2A

	retlw   0x6B

	retlw   0x6B

	retlw   0x80            ; 723. byte

	org     0x300           ; Zacetek novega 256 byte bloka
;********************************************************************
;*      Sveta noc                                                   *
;********************************************************************
pesem_4                         ; dolzina pesmi 46 tonov
	addwf   pcl,f           ; 768. byte
	
	retlw   0x38
	retlw   0x1A
	retlw   0x28
	retlw   0x65

	retlw   0x38
	retlw   0x1A
	retlw   0x28
	retlw   0x65

	retlw   0x4F
	retlw   0x2F
	retlw   0x6C

	retlw   0x4D
	retlw   0x2D
	retlw   0x68
	
	retlw   0x4A
	retlw   0x2A
	retlw   0x3D
	retlw   0x1C
	retlw   0x2A

	retlw   0x38
	retlw   0x1A
	retlw   0x28
	retlw   0x65

	retlw   0x4A
	retlw   0x2A
	retlw   0x3D
	retlw   0x1C
	retlw   0x2A

	retlw   0x38
	retlw   0x1A
	retlw   0x28
	retlw   0x65
	
	retlw   0x4F
	retlw   0x2F
	retlw   0x2F
	retlw   0x2F
	retlw   0x2C

	retlw   0xBD
	
	retlw   0x2D
	retlw   0x28
	retlw   0x25
	retlw   0x28
	retlw   0x26
	retlw   0x23
	
	retlw   0x61

	retlw   0x80            ; 805. byte

;********************************************************************
;*      Love me tender                                              *
;********************************************************************
pesem_5                         ; dolzina pesmi 74 tonov
	addwf   pcl,f           ; 806. byte

	retlw   0x23
	retlw   0x28
	retlw   0x27
	retlw   0x28

	retlw   0x2A
	retlw   0x25
	retlw   0x4A
	
	retlw   0x28
	retlw   0x27
	retlw   0x25
	retlw   0x27
	
	retlw   0x88
	
	retlw   0x23
	retlw   0x28
	retlw   0x27
	retlw   0x28

	retlw   0x2A
	retlw   0x25
	retlw   0x4A

	retlw   0x28
	retlw   0x27
	retlw   0x25
	retlw   0x27

	retlw   0x88

	retlw   0x2C
	retlw   0x2C
	retlw   0x1C
	retlw   0x3C

	retlw   0x2C
	retlw   0x2C
	retlw   0x4C

	retlw   0x2C
	retlw   0x2A
	retlw   0x28
	retlw   0x2A

	retlw   0x8C

	retlw   0x2C
	retlw   0x2C
	retlw   0x2D
	retlw   0x2C

	retlw   0x2A
	retlw   0x25
	retlw   0x4A

	retlw   0x28
	retlw   0x27
	retlw   0x25
	retlw   0x27

	retlw   0x68
	retlw   0x20            ; 855. byte

	retlw   0x2C
	retlw   0x2C
	retlw   0x1C
	retlw   0x3C

	retlw   0x2C
	retlw   0x2C
	retlw   0x4C

	retlw   0x2C
	retlw   0x2A
	retlw   0x28
	retlw   0x2A

	retlw   0x8C

	retlw   0x2C
	retlw   0x2C
	retlw   0x2D
	retlw   0x2C

	retlw   0x2A
	retlw   0x25
	retlw   0x4A

	retlw   0x28
	retlw   0x27
	retlw   0x3C
	retlw   0x1A

	retlw   0x88
	
	retlw   0x80            ; 889. byte

;********************************************************************
;*      Oh, when the saints go marchin`in                           *
;********************************************************************
pesem_6                         ; dolzina pesmi 37 tonov
	addwf   pcl,f           ; 890. byte
	
	retlw   0x15
	retlw   0x19
	retlw   0x1A

	retlw   0x4C
	retlw   0x10
	retlw   0x15
	retlw   0x19
	retlw   0x1A

	retlw   0x4C
	retlw   0x10
	retlw   0x15
	retlw   0x19
	retlw   0x1A

	retlw   0x2C
	retlw   0x29
	retlw   0x25
	retlw   0x29

	retlw   0x47
	retlw   0x10
	retlw   0x19
	retlw   0x19
	retlw   0x17

	retlw   0x35
	retlw   0x15
	retlw   0x29
	retlw   0x2C

	retlw   0x1C
	retlw   0x4A
	retlw   0x1A
	retlw   0x19
	retlw   0x1A

	retlw   0x2C
	retlw   0x29
	retlw   0x25
	retlw   0x27

	retlw   0x45
	retlw   0x40            ; 927. byte

;********************************************************************
;*      My bonnie is over the ocean.                                *
;********************************************************************
pesem_7                         ; dolzina pesmi 62 tonov
	addwf   pcl,f           ; 928. byte

	retlw   0x24

	retlw   0x2D
	retlw   0x2B
	retlw   0x29
	retlw   0x2B
	retlw   0x29
	retlw   0x26

	retlw   0x24
	retlw   0x81
	retlw   0x24

	retlw   0x2D
	retlw   0x2B
	retlw   0x29
	retlw   0x29
	retlw   0x28
	retlw   0x29

	retlw   0xAB
	retlw   0x24

	retlw   0x2D
	retlw   0x2B
	retlw   0x29
	retlw   0x2B
	retlw   0x29
	retlw   0x26

	retlw   0x24
	retlw   0x81
	retlw   0x24

	retlw   0x26
	retlw   0x2B
	retlw   0x29
	retlw   0x28
	retlw   0x26
	retlw   0x28

	retlw   0xA9
	retlw   0x20

	retlw   0x64
	retlw   0x69

	retlw   0x66
	retlw   0x4B
	retlw   0x29

	retlw   0x28
	retlw   0x28
	retlw   0x28
	retlw   0x28
	retlw   0x26
	retlw   0x28
	
	retlw   0x49
	retlw   0x2B
	retlw   0x6D

	retlw   0x64
	retlw   0x69

	retlw   0x66
	retlw   0x4B
	retlw   0x29

	retlw   0x28
	retlw   0x28
	retlw   0x28
	retlw   0x28
	retlw   0x26
	retlw   0x28
	
	retlw   0xA9

	retlw   0x80            ; 990. byte

;********************************************************************
;*      That's all folks!                                           *
;********************************************************************
	end






